pub enum CuLogLevel {
Debug = 0,
Info = 1,
Warning = 2,
Error = 3,
Critical = 4,
}Expand description
Log levels for Copper.
Variants
Debug = 0
Detailed information useful during development
Info = 1
General information about system operation
Warning = 2
Indication of potential issues that don’t prevent normal operation
Error = 3
Issues that might disrupt normal operation but don’t cause system failure
Critical = 4
Critical errors requiring immediate attention, usually resulting in system failure
Implementations
Sourceimpl CuLogLevel
impl CuLogLevel
Sourcepub const fn enabled(self, max_level: CuLogLevel) -> bool
pub const fn enabled(self, max_level: CuLogLevel) -> bool
Returns true if this log level is enabled for the given max level
The log level is enabled if it is greater than or equal to the max level. For example, if max_level is Info, then Info, Warning, Error and Critical are enabled, but Debug is not.