CuLogEntry

Struct CuLogEntry 

pub struct CuLogEntry {
    pub time: CuTime,
    pub level: CuLogLevel,
    pub msg_index: u32,
    pub paramname_indexes: SmallVec<[u32; 10]>,
    pub params: SmallVec<[Value; 10]>,
}
This is the basic structure for a log entry in Copper.

Fields

time: CuTimelevel: CuLogLevelmsg_index: u32paramname_indexes: SmallVec<[u32; 10]>params: SmallVec<[Value; 10]>

Implementations

Source

impl CuLogEntry

pub fn new(msg_index: u32, level: CuLogLevel) -> Self

msg_index is the interned index of the message.

pub fn add_param(&mut self, paramname_index: u32, param: Value)

Add a parameter to the log entry. paramname_index is the interned index of the parameter name.